@@ -7,9 +7,7 @@ use swc_common::{
     Mark, DUMMY_SP,
 };
 use swc_ecma_ast::*;
-use swc_ecma_utils::{
-    collect_decls, ident::IdentLike, ExprExt, Id, IsEmpty, ModuleItemLike, StmtLike, Value,
-};
+use swc_ecma_utils::{collect_decls, ExprExt, Id, IsEmpty, ModuleItemLike, StmtLike, Value};
 use swc_ecma_visit::{
     as_folder, noop_visit_mut_type, noop_visit_type, Fold, Visit, VisitMut, VisitMutWith, VisitWith,
 };
