@@ -11,7 +11,7 @@ use swc_atoms::js_word;
 use swc_common::collections::{AHashMap, AHashSet};
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::ext::ExprRefExt;
-use swc_ecma_utils::{ident::IdentLike, Id};
+use swc_ecma_utils::Id;
 use tracing::{span, Level};
 
 use super::{Inlining, Phase};
